@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/box.c,v 1.11 2011/05/16 16:21:56 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/box.c,v 1.13 2011/06/09 16:11:41 cvsps Exp $
  */
 
 #define _INCLUDE_FROM_BOX_C_
@@ -38,14 +38,18 @@
 #include "attr.e"
 #include "auxtext.e"
 #include "box.e"
+#include "choice.e"
 #include "cmd.e"
 #include "color.e"
 #include "cursor.e"
 #include "cutpaste.e"
+#include "dialog.e"
 #include "drawing.e"
+#include "dup.e"
 #include "file.e"
 #include "grid.e"
 #include "mainloop.e"
+#include "mark.e"
 #include "msg.e"
 #include "obj.e"
 #include "pattern.e"
@@ -517,6 +521,25 @@ void DrawBox(input)
    }
 }
 
+void MakeBoxObjFromBoundingBox()
+{
+   if (topSel == NULL) {
+      MsgBox(TgLoadCachedString(CSTID_NO_OBJ_SELECTED), TOOL_NAME, INFO_MB);
+      return;
+   }
+   if (curChoice == VERTEXMODE) SetCurChoice(NOTHING);
+
+   HighLightReverse();
+   CreateBoxObj(selObjLtX, selObjLtY, selObjRbX, selObjRbY, TRUE);
+   SelectTopObj();
+   RecordNewObjCmd();
+   RedrawAnArea(botObj, selLtX-GRID_ABS_SIZE(1), selLtY-GRID_ABS_SIZE(1),
+         selRbX+GRID_ABS_SIZE(1), selRbY+GRID_ABS_SIZE(1));
+   HighLightForward();
+   justDupped = FALSE;
+   SetFileModified(TRUE);
+}
+
 void SaveBoxObj(FP, ObjPtr)
    FILE *FP;
    struct ObjRec *ObjPtr;
