@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/oval.c,v 1.9 2011/05/16 16:21:58 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/oval.c,v 1.11 2011/06/09 16:11:42 cvsps Exp $
  */
 
 #define _INCLUDE_FROM_OVAL_C_
@@ -42,10 +42,13 @@
 #include "color.e"
 #include "cursor.e"
 #include "cutpaste.e"
+#include "dialog.e"
 #include "drawing.e"
+#include "dup.e"
 #include "file.e"
 #include "grid.e"
 #include "mainloop.e"
+#include "mark.e"
 #include "msg.e"
 #include "obj.e"
 #include "oval.e"
@@ -715,6 +718,31 @@ void DrawOval(input)
    }
 }
 
+void MakeOvalObjFromBoundingBox()
+{
+   struct BBRec obbox;
+
+   if (topSel == NULL) {
+      MsgBox(TgLoadCachedString(CSTID_NO_OBJ_SELECTED), TOOL_NAME, INFO_MB);
+      return;
+   }
+   if (curChoice == VERTEXMODE) SetCurChoice(NOTHING);
+
+   HighLightReverse();
+   obbox.ltx = selObjLtX;
+   obbox.lty = selObjLtY;
+   obbox.rbx = selObjRbX;
+   obbox.rby = selObjRbY;
+   CreateOvalObj(&obbox, TRUE);
+   SelectTopObj();
+   RecordNewObjCmd();
+   RedrawAnArea(botObj, selLtX-GRID_ABS_SIZE(1), selLtY-GRID_ABS_SIZE(1),
+         selRbX+GRID_ABS_SIZE(1), selRbY+GRID_ABS_SIZE(1));
+   HighLightForward();
+   justDupped = FALSE;
+   SetFileModified(TRUE);
+}
+
 void SaveOvalObj(FP, ObjPtr)
    FILE *FP;
    struct ObjRec *ObjPtr;
