@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2009, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2011, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm2/home/cvs/bc-src/tgif/util.c,v 1.9 2009/01/09 22:25:32 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/util.c,v 1.13 2011/05/16 16:22:00 william Exp $
  */
 
 #define _INCLUDE_FROM_UTIL_C_
@@ -77,7 +77,7 @@ int UtilStrCpyN(pszDest, nMaxDestSz, pszSrc)
    char *pszDest, *pszSrc;
    int nMaxDestSz;
 {
-   int len;
+   int len=0;
 
    if (pszDest != NULL && nMaxDestSz > 0) *pszDest = '\0';
    if (pszDest == NULL || pszSrc == NULL || nMaxDestSz <= 0) return 0;
@@ -89,6 +89,20 @@ int UtilStrCpyN(pszDest, nMaxDestSz, pszSrc)
    return len;
 }
 
+int UtilStrCpy(pszDest, pszSrc)
+   char *pszDest, *pszSrc;
+   /* safe copy byte by byte from pszSrc to pszDest */
+{
+   int len=0;
+
+   if (pszDest == NULL || pszSrc == NULL) return 0;
+
+   while (((*pszDest++)=(*pszSrc++)) != '\0') {
+      len++;
+   }
+   return len;
+}
+
 void UtilLeftTrim(pszStr)
    char *pszStr;
    /* pszStr must be terminated by '\0' */
@@ -459,6 +473,7 @@ int UtilCopyFile(pszFromFile, pszToFile)
    char buf[0x1000];
    int bytes_read=0;
    int fd1=(-1), fd2=(-1);
+   mode_t mode=((tmpFileMode == 0) ? 0700 : tmpFileMode);
 
    if ((fd1=open(pszFromFile, O_RDONLY)) == (-1)) return TG_REMOTE_STATUS_READ;
    if (UtilPathExists(pszToFile)) {
@@ -467,8 +482,7 @@ int UtilCopyFile(pszFromFile, pszToFile)
          return TG_REMOTE_STATUS_WRITE;
       }
    } else {
-      if ((fd2=open(pszToFile, O_WRONLY|O_CREAT|O_TRUNC, tmpFileMode)) ==
-            (-1)) {
+      if ((fd2=open(pszToFile, O_WRONLY|O_CREAT|O_TRUNC, mode)) == (-1)) {
          close(fd1);
          return TG_REMOTE_STATUS_WRITE;
       }
@@ -497,6 +511,7 @@ int UtilConcatFile(pszFromFile1, pszFromFile2, pszToFile)
    char buf[0x1000];
    int bytes_read=0;
    int fd1=(-1), fd2=(-1), fd3=(-1);
+   mode_t mode=((tmpFileMode == 0) ? 0700 : tmpFileMode);
 
    if ((fd1=open(pszFromFile1, O_RDONLY)) == (-1)) return TG_REMOTE_STATUS_READ;
    if ((fd2=open(pszFromFile2, O_RDONLY)) == (-1)) {
@@ -510,8 +525,7 @@ int UtilConcatFile(pszFromFile1, pszFromFile2, pszToFile)
          return TG_REMOTE_STATUS_WRITE;
       }
    } else {
-      if ((fd3=open(pszToFile, O_WRONLY|O_CREAT|O_TRUNC, tmpFileMode)) ==
-            (-1)) {
+      if ((fd3=open(pszToFile, O_WRONLY|O_CREAT|O_TRUNC, mode)) == (-1)) {
          close(fd1);
          close(fd2);
          return TG_REMOTE_STATUS_WRITE;
